@@ -13,7 +13,7 @@ illustrate.boxplot <- function(x){
   x.ok <- x[x >= iqr[1]-1.5*diff(iqr) & x <= iqr[2]+1.5*diff(iqr)]
   low.fence <- max(min(x.ok), iqr[1]-1.5*diff(iqr))
   upp.fence <- min(max(x.ok), iqr[2]+1.5*diff(iqr))
-  gg <- ggplot(DF, aes_string(x = "x", y = "y")) +
+  gg <- ggplot(DF, aes(x = .data$x, y = .data$y)) +
     theme_minimal() + 
     theme(axis.title.y=element_blank(), axis.text.y=element_blank(),
           axis.ticks.y=element_blank(),
@@ -28,35 +28,35 @@ illustrate.boxplot <- function(x){
                color = "#5C88DA") + 
     geom_vline(xintercept = upp.fence, linetype = "dotted",
                color = "#5C88DA") + 
-    geom_point(aes_string(x = "x", y = "y"), data = DFiqr, pch = "|", size = 10, 
+    geom_point(aes(x = .data$x, y = .data$y), data = DFiqr, pch = "|", size = 10, 
                position = position_nudge(y=0.03), color = "#CC0C00") +
-    geom_line(data = DFiqr, aes_string(x = "x", y = "y"), 
+    geom_line(data = DFiqr, aes(x = .data$x, y = .data$y), 
               color = "#CC0C00", position = position_nudge(y = 0.02)) +
     annotate(geom = "text", x = mean(iqr), y = 1.6, label = "middle 50%",
              color = "#CC0C00") +
-    geom_point(aes_string(x = "x", y = "y"), data = DFmin, pch = "|", size = 10, 
+    geom_point(aes(x = .data$x, y = .data$y), data = DFmin, pch = "|", size = 10, 
                position = position_nudge(y=0.03), color = "#CC0C00") +
-    geom_line(data = DFmin, aes_string(x = "x", y = "y"), 
+    geom_line(data = DFmin, aes(x = .data$x, y = .data$y), 
               color = "#CC0C00", position = position_nudge(y = 0.02)) +
     annotate(geom = "text", x = mean(DFmin$x), y = 1.6, label = "lower 25%",
              color = "#CC0C00") +
-    geom_point(aes_string(x = "x", y = "y"), data = DFmax, pch = "|", size = 10, 
+    geom_point(aes(x = .data$x, y = .data$y), data = DFmax, pch = "|", size = 10, 
                position = position_nudge(y=0.03), color = "#CC0C00") +
-    geom_line(data = DFmax, aes_string(x = "x", y = "y"), 
+    geom_line(data = DFmax, aes(x = .data$x, y = .data$y), 
               color = "#CC0C00", position = position_nudge(y = 0.02)) +
     annotate(geom = "text", x = mean(DFmax$x), y = 1.6, label = "upper 25%",
              color = "#CC0C00") + 
-    geom_point(aes_string(x = "x", y = "y"), data = DFwhisker, pch = "|", size = 10, 
+    geom_point(aes(x = .data$x, y = .data$y), data = DFwhisker, pch = "|", size = 10, 
                position = position_nudge(y=0.03), color = "#CC0C00") +
-    geom_line(data = DFwhisker, aes_string(x = "x", y = "y"), 
+    geom_line(data = DFwhisker, aes(x = .data$x, y = .data$y), 
               color = "#CC0C00", position = position_nudge(y = 0.02)) +
     annotate(geom = "text", x = mean(iqr), y = 1.85, 
              label = "maximum range of whiskers", color = "#CC0C00") +
-    geom_line(data = DFout1, aes_string(x = "x", y = "y"), 
+    geom_line(data = DFout1, aes(x = .data$x, y = .data$y), 
               color = "#CC0C00", position = position_nudge(y = 0.02)) +
     annotate(geom = "text", x = mean(DFout1$x), y = 1.85, 
              label = "outlier region", color = "#CC0C00") +
-    geom_line(data = DFout2, aes_string(x = "x", y = "y"), 
+    geom_line(data = DFout2, aes(x = .data$x, y = .data$y), 
               color = "#CC0C00", position = position_nudge(y = 0.02)) +
     annotate(geom = "text", x = mean(DFout2$x), y = 1.85, 
              label = "outlier region", color = "#CC0C00") +
